#!/bin/bash
#
# Version: 0.55 (2013.04.14)
# Info: CoMinder SpaceStat - collection of scripts to gather 
#       and report information about space used by objects in DB
#       See more details in README.txt
#
# Developed by: CoMinder, http://www.cominder.eu, Andrey Chervonets (ACE) 
# Changes:
# 2011.12.28: 0.50: ACE: 1st version using repository DB for all remote DB
# 2012.02.16: 0.51: ACE: for each DB personally, no need central repository and DB-links
#                      : repository DB may be supported in later versions 
# 2012.06.27: 0.53: ACE: do snapshot ALL with one call - really do 2 snaps internally for each snap type
# 2012.10.16: 0.54: ACE: use oraenv to set environment for connecting to DB instance
# 2013.04.14: 0.55: ACE: try to use default oraenv location if it is not present in current PATH 

if [ -z "${1}" ] ; then
   echo "Usage: ${0} ORACLE_SID"
   exit 1
else
  ORACLE_SID=${1}
  export ORACLE_SID
  BASE_DIR=`dirname $0`
fi

# set environment variables - use oraenv
# it should be visible in regular PATH, for example: /usr/local/bin/oraenv
which oraenv 1>/dev/null 2>&1
if [ ! $? -eq 0 ] ; then
  # location is unknown
  # test default location
  if [ -x /usr/local/bin/oraenv ] ; then
     PATH=${PATH}:/usr/local/bin
  else
     echo "Error: oraenv location unknown!!! "
     # if required - replace support@cominder.eu with your support e-mail and uncomment next line
     # replace mail with mailx on some OS
     # echo "Error: oraenv location unknown!!! " | mail -s "`hostname` $0 have problem" support@cominder.eu
     exit 2
  fi

fi

# NOTE: database should be registered in /etc/oratab
# but You can implement it in any fashion You like
# 
ORAENV_ASK=NO
. oraenv
ORAENV_ASK=

# specify what snapshot types are required 
# DBS - for DB segments (DBA_SEGMENTS)
# DBF - for DB files info (DBA_DATA_FILES, DBA_TEMP_FILES, redo-logs, control-files)
# or ALL - for ALL supported snapshot types in DB (DBS+DBF)
sqlplus "/ as sysdba" <<EOF
@${BASE_DIR}/sps_snap.sql ALL 
-- @${BASE_DIR}/sps_snap.sql DBS
-- @${BASE_DIR}/sps_snap.sql DBF
quit
EOF



