/* upgrade SPACESTAT objects
from version: 0.54
  to version: 0.55
  
 date: 16.06.2013
*/   

spool sps_upgrade_054_055.log
spool
-- check existing version
set lines 300
set pages 100

col MODULE_NAME     format a15            
col MODULE_VERSION  format a15 
col STATUS          format a15
col INSTALL_TS      format a10
col UPGRADE_TS      format a10             
col MODULE_INFO     format a30

set lines 300
set pages 100            

prompt == This script is intended for upgrade from version 0.54 only ==
prompt == Check latest record for current version ==
select MODULE_NAME
, MODULE_VERSION
, STATUS
, INSTALL_TS
, UPGRADE_TS
, MODULE_INFO
from SPACESTAT.SPS_VERSION
order by UPGRADE_TS
/                 

prompt Press Enter key to continue with upgrade or presss Ctrl+C (and then Enter) to terminate
pause

insert into SPACESTAT.SPS_VERSION(module_name,module_info,module_version,status,install_ts,upgrade_ts)
  values('SPS_ORADB','SpaceStat for Oracle DB','0.55','upgrade',sysdate,sysdate);
commit;   
-- set session vars for faster full scan and indexing
alter session set workarea_size_policy='MANUAL';
alter session set hash_area_size=52428800;
alter session set sort_area_size=52428800;
alter session set db_file_multiblock_read_count=64;
--- tables --
-- add  PARTITION_NAME field 
alter table SPACESTAT.SPS_SNAP_DATA drop constraint SPS_SNAP_DATA_PK;
-- update rows for NULL partitions we will need this for PK
update SPACESTAT.SPS_SNAP_DATA set PARTITION_NAME='--NONE--' where PARTITION_NAME is null;
commit;
-- 
-- drop INDEX SPACESTAT.SPS_SNAP_DATA_PK  - not required - dropped by drop constraint 

-- add not null constraint for partition_name field
alter table SPACESTAT.SPS_SNAP_DATA modify PARTITION_NAME not null;
---- UK-PK-Index, 0.55
CREATE UNIQUE INDEX SPACESTAT.SPS_SNAP_DATA_PK ON SPACESTAT.SPS_SNAP_DATA
  (
    SNAP_ID,
    DBID,
    SNAP_TYPE,
    OWNER,
    SEGMENT_TYPE,
    SEGMENT_NAME,
    PARTITION_NAME
  ) tablespace SPACESTAT;
  
-- PK, 0.55  
alter table SPACESTAT.SPS_SNAP_DATA 
add constraint SPS_SNAP_DATA_PK primary key
(
  SNAP_ID,
  DBID,
  SNAP_TYPE,
  OWNER,
  SEGMENT_TYPE,
  SEGMENT_NAME,
  PARTITION_NAME  
)
USING INDEX tablespace SPACESTAT
/ 

-- set normal settings
alter session set workarea_size_policy='AUTO';

prompt == Database structures upgrade completed ==

-- create new code
@@../create/cre_code_snap.sql
@@../create/cre_code_purge.sql

prompt == Database package upgrade completed ==

-- when completed
update SPACESTAT.SPS_VERSION set status='VALID',upgrade_ts=sysdate 
 where module_name='SPS_ORADB' and module_version='0.55'
   and status='upgrade';
commit;

/* Installation done
  next: check for invalid objects
*/
col OBJECT_TYPE format a16
col OBJECT_NAME format a30
col STATUS format a10  

prompt == Listing SPACESTAT objects, check all are VALID and recompile if required ==

select OBJECT_TYPE, OBJECT_NAME, STATUS 
  from dba_objects 
 where owner='SPACESTAT'
order by STATUS, OBJECT_TYPE, OBJECT_NAME;

prompt == Show latest record for current version ==
select MODULE_NAME
, MODULE_VERSION
, STATUS
, INSTALL_TS
, UPGRADE_TS
, MODULE_INFO
from SPACESTAT.SPS_VERSION
where UPGRADE_TS>SYSDATE-1 
order by UPGRADE_TS
/                 

spool
prompt == Check spooled .log file for any errors. == 
prompt == Database part completed, next: update OS scripts used for scheduled snapshoting: use ALL or DBS,DBF == 
