
/* 
  SPS_CREATE - version 0.54, 2012.06.27
  0.55 - 2013.06.16 - installation steps are the same as in 0.54
*/  

/* 
  Set of actions to install CoMinder SpaceStat into new database
  this is for new setup
  for upgrade - use upgrade script(s) specified in UPGRADE.txt
  
  Please, review ALL the scripts before execute!
  Manual installation executing DDL/scripts one by one may be better solution in this version.
  
  Installation by user with DBA privilegies (or check the scripts to see what exactly required)
  Usage by DBA or SPACESTAT user, having limited privilegies granted!
  
  Changes:
  2012.06.27: 0.53: ACE: 1st public version
  2012.10.16: 0.54: ACE: add settings table and values, add code to purge old data
  2013.06.16: 0.55: ACE: some notes 
*/  
set lines 300
set pages 1000
spool sps_create.log
/* 
  First of all we create tablespace(s)
   
*/
@@cre_tablespace.sql

/* 
  Then we need to create SPACESTAT user and schema and give select rights of some DBA_ views 
*/
@@cre_user.sql

/* 
  Next: Create tables, indexes, constraints

   Ignore DROP errors like:
ORA-02289: sequence does not exist
ORA-00942: table or view does not exist
    
*/
@@cre_tables.sql
@@cre_settings.sql

/* Views */
@@cre_views.sql

/* 
  Next: Create Code: Packages, Procedures, Functions  
*/
@@cre_code_snap.sql
@@cre_code_purge.sql


/* Installation done
  next: check for invalid objects
*/
col OBJECT_TYPE format a16
col OBJECT_NAME format a30
col STATUS format a10  

select OBJECT_TYPE, OBJECT_NAME, STATUS 
  from dba_objects 
 where owner='SPACESTAT'
order by STATUS, OBJECT_TYPE, OBJECT_NAME;

/* 
  recompile if required   
  when OK - execute following SQL, just to track version number for later upgrade
*/  
update SPACESTAT.SPS_VERSION set status='VALID',upgrade_ts=sysdate 
 where module_name='SPS_ORADB' and module_version='0.55'
   and status='install';
commit;

prompt == Show latest record for current version ==
select MODULE_NAME
, MODULE_VERSION
, STATUS
, INSTALL_TS
, UPGRADE_TS
, MODULE_INFO
from SPACESTAT.SPS_VERSION
where UPGRADE_TS>SYSDATE-1 
order by UPGRADE_TS
/                 

spool
spool off

prompt check spool file for errors. 
prompt  During first install - ignore DROP errors like:
prompt    ORA-02289: sequence does not exist
prompt    ORA-00942: table or view does not exist

