/*
 SpaceStat - reports snapshots that should be kept in DB 
 according to current configuration 
  per year
  per month
  per week
  per day

/* List snaps of each pariod type. Note: all values must be set or NO rows will be returned */

set echo off
prompt 
prompt === STATSPACK - Actual snapshots report ===
prompt === (obsolete snapshot according to current retention settings not displayed) === 

select DBID from v$database;
select to_char(sysdate,'DD.MM.YYYY HH24:MI:SS') SYS_DATE  from dual;
select to_char(current_date,'DD.MM.YYYY HH24:MI:SS') curr_date from dual;

col SUMMARY format a50 
col SNAP_TYPE format a10

select DBID, SNAP_TYPE, min(start_time) FROM_DATE, max(start_time) TO_DATE, count(1) SNAPS_COUNT 
from  spacestat.sps_snaps
group by DBID, SNAP_TYPE;

/* daily data */
select 'Daily snaps to keep for '||value||' days' SUMMARY from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_DAILY_DATA_COUNT'
union (
select 'Daily snaps time: whatever You schedule it!' SUMMARY  from dual
);
 
select DBID, SNAP_ID, SNAP_TYPE, start_time
from spacestat.sps_snaps 
where start_time >= sysdate-(select value from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_DAILY_DATA_COUNT')
order by start_time;

/* weekly data */
select 'Weekly snaps to keep for '||to_number(value)||' weeks ='||7*to_number(value)||' days' SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_WEEKLY_DATA_COUNT'
union (
select 'Weekly snaps day:'||value SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_WEEKLY_DATA_DAY'
);

select DBID, SNAP_ID, SNAP_TYPE, start_time
from spacestat.sps_snaps 
where start_time>=sysdate-(select 7*to_number(value) from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_WEEKLY_DATA_COUNT') 
  and to_char(start_time,'DY')=(select value from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_WEEKLY_DATA_DAY')
order by start_time;

/* monthly data */
select 'Monthly snaps to keep for '||to_number(value)||' months ' SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_MONTHLY_DATA_COUNT'
union (
select 'Monthly snaps day:'||value||'.MM.YYYY' SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_MONTHLY_DATA_DAY'
);

select DBID, SNAP_ID, SNAP_TYPE, start_time
from spacestat.sps_snaps 
where start_time>=ADD_MONTHS(sysdate,-1*(select to_number(value) from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_MONTHLY_DATA_COUNT')) 
  and to_char(start_time,'DD')=(select value from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_MONTHLY_DATA_DAY')
order by start_time;

/* Yearly data */
select 'Yearly snaps to keep for '||to_number(value)||' years ' SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_YEARLY_DATA_COUNT'
union (
select 'Yearly snaps day:'||value||'.YYYY' SUMMARY  from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_YEARLY_DATA_DAY'
);

select DBID, SNAP_ID, SNAP_TYPE, start_time
from spacestat.sps_snaps 
where start_time>=ADD_MONTHS(sysdate,-1*12*(select to_number(value) from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_YEARLY_DATA_COUNT')) 
  and to_char(start_time,'DD.MM')=(select value from SPACESTAT.SPS_SETTINGS where NAME='RETENTION_KEEP_YEARLY_DATA_DAY')
order by start_time;


